Learn R Programming

allhomes (version 0.3.0)

get_ah_division_ids: Get Allhomes division (suburb) IDs (name, state, postcode, ID).

Description

Get Allhomes division (suburb) names and IDs for a (vector of) suburb(s). The input must be a character vector of suburbs with states (of the form "Acton, ACT"), and it uses the Allhomes API to query internal Allhomes data for matching entries. If successful, it will return a tibble with Allhomes division names, states, postcodes and IDs. If unsuccessful, it will skip the entry.

Usage

get_ah_division_ids(x, quiet = FALSE)

Value

A tibble with Allhomes data for the division (suburb), state, postcode, and ID.

Arguments

x

A character vector (or scalar) with suburb + state entries (e.g. "Balmain, NSW")

quiet

If TRUE then messages are suppressed.

Examples

Run this code
# \donttest{
get_ah_division_ids(c("Acton, ACT", "Balmain, NSW"))
# }

Run the code above in your browser using DataLab