extract_past_sales_data: Extract Allhomes past sales data for a single division ID and year.
Description
Extract Allhomes past sales data for a division ID and year. The division
ID is the ID for a specific division (suburb). This is an internal function
that gets called by vectorised get_past_sales_data(). This function is
currently exported but this may change in the future.