Get Allhomes division (suburb) names and IDs for a (vector of) suburb(s).
The input must be a character vector of suburbs with states (of the form
"Acton, ACT"), and it uses the Allhomes API to query internal Allhomes data
for matching entries. If successful, it will return a tibble with Allhomes
division names, states, postcodes and IDs. If unsuccessful, it will skip the
entry.